| slm_effect_sizes | R Documentation |
Compute effect sizes for mass-univariate GLM analysis.
slm_effect_sizes(
X,
Y,
predictors,
output = c("F", "p", "etasq", "partial.etasq", "cohens.f", "rsq", "power")
)
X |
numerical matrix, the design or model matrix, typically created from the demographics data using |
Y |
numerical matrix, the target value, typically neuroimaging data |
predictors |
vector of character strings, the names of the predictors in the model matrix |
output |
vector of pre-defined character strings, defined what values to return. Leave alone if in doubt. |
named list with entries according to the output parameter. By default F= the F value map, p = the uncorrected p value map, etasq = the eta squared value map, , parial.etasq = the partial eta squared value map, rsq = the r squared value map. power = the power of the F test (1 minus Type II error probability) to detect an effect of the computed effect size (see 'cohens.f' entry) given the sample and a significance level of 0.05.
C Ecker, documentation by T Schaefer ″
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.